@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Literal;
-BEGIN {
-  $Bread::Board::Declare::Literal::VERSION = '0.10';
+{
+  $Bread::Board::Declare::Literal::VERSION = '0.11';
 }
 use Moose;
 # ABSTRACT: subclass of Bread::Board::Literal for Bread::Board::Declare
@@ -23,7 +23,7 @@ Bread::Board::Declare::Literal - subclass of Bread::Board::Literal for Bread::Bo
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -31,25 +31,13 @@ This is a custom subclass of L<Bread::Board::Literal> which does the
 L<Bread::Board::Declare::Role::Service> role. See those two modules for more
 details.
 
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Bread::Board::Declare|Bread::Board::Declare>
-
-=back
-
 =head1 AUTHOR
 
 Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2012 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
