@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Meta::Role::Class;
-BEGIN {
-  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.10';
+{
+  $Bread::Board::Declare::Meta::Role::Class::VERSION = '0.11';
 }
 use Moose::Role;
 # ABSTRACT: class metarole for Bread::Board::Declare
@@ -13,8 +13,7 @@ use List::MoreUtils qw(any);
 sub get_all_services {
     my $self = shift;
     return map { $_->associated_service }
-           grep { $_->has_associated_service }
-           grep { Moose::Util::does_role($_, 'Bread::Board::Declare::Meta::Role::Attribute') }
+           grep { Moose::Util::does_role($_, 'Bread::Board::Declare::Meta::Role::Attribute::Service') }
            $self->get_all_attributes;
 }
 
@@ -46,7 +45,7 @@ Bread::Board::Declare::Meta::Role::Class - class metarole for Bread::Board::Decl
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -59,25 +58,13 @@ classes.
 
 Returns all of the services that are associated with attributes in this class.
 
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Bread::Board::Declare|Bread::Board::Declare>
-
-=back
-
 =head1 AUTHOR
 
 Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2012 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
