@@ -1,6 +1,6 @@
 package Bread::Board::Declare::Meta::Role::Instance;
-BEGIN {
-  $Bread::Board::Declare::Meta::Role::Instance::VERSION = '0.10';
+{
+  $Bread::Board::Declare::Meta::Role::Instance::VERSION = '0.11';
 }
 use Moose::Role;
 
@@ -21,29 +21,17 @@ Bread::Board::Declare::Meta::Role::Instance
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =for Pod::Coverage inline_get_is_lvalue
 
-=head1 SEE ALSO
-
-Please see those modules/websites for more information related to this module.
-
-=over 4
-
-=item *
-
-L<Bread::Board::Declare|Bread::Board::Declare>
-
-=back
-
 =head1 AUTHOR
 
 Jesse Luehrs <doy at tozt dot net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2012 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
